@@ -1,4 +1,5 @@
-import ctxlogger as logger
+from . import ctxlogger as logger
+from .defs import KEY_AUTH, KEY_CID
 import time
 from fastapi import FastAPI, Request
 from fastapi.responses import JSONResponse, PlainTextResponse
@@ -11,12 +12,6 @@ import uuid
 c = pc.Counter('nbapi_request_count', 'Count the total number of incoming request', ['path', 'status_code', 'cid'])
 g = pc.Gauge('nbapi_request_duration', 'Gauge the duration of incoming request', ['path', 'status_code', 'cid'])
 
-KEY_ID: str = 'id'
-KEY_INPUT: str = 'input'
-KEY_AUTH: str = 'auth'
-KEY_CID: str = 'cid'
-KEY_OUTPUT: str = 'output'
-
 
 class AuthError(Exception):
     pass
