@@ -1,5 +1,5 @@
 import logging
-from .nbapis import KEY_CID, KEY_ID
+from .defs import KEY_CID, KEY_ID
 
 _loggers = {
     'debug': logging.debug,
